package graphs;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;

public class Main {
	private static List<Vertex> nodes;
	private static List<Edge> edges;

	private static void addLane(final int laneId, final int sourceLocNo, final int destLocNo,
			final int duration) {
		final Edge lane = new Edge(laneId, nodes.get(sourceLocNo),
				nodes.get(destLocNo), duration);
		edges.add(lane);
	}
	
	public static void main(final String[] args) {
		nodes = new ArrayList<Vertex>();
		edges = new ArrayList<Edge>();
		int vertexes = 0;
		int highways = 0;
		String line;
		BufferedReader br = null;
		try {
			br = new BufferedReader(new FileReader("graph.in"));
			line = br.readLine();
			String[] buffer = line.split(" ");
			vertexes = Integer.parseInt(buffer[0]);
			if (vertexes < 2 || vertexes > 300) {
				throw new Exception("The cities must be between 2 and 300.");
			}
			
			highways = Integer.parseInt(buffer[1]);
			
			Vertex location;
			for (int i = 0; i < highways; i++) {
				location = new Vertex("" + i, "" + i);
				nodes.add(location);
			}
			
			int before;
			int after;
			int weight;
			
			for (int i = 1; i <= highways; i++) {
				line = br.readLine();
				buffer = line.split(" ");

				before = Integer.parseInt(buffer[0]);
				after = Integer.parseInt(buffer[1]);
				weight = Integer.parseInt(buffer[2]);
				
				if (weight < 1 || weight > 1000) {
					throw new Exception("Distance must be between 1 and 1000.");
					
				}

			   	addLane(i, before, after, weight);
				addLane(i, after, before, weight);
			}
			
		} catch (Exception e) {
			System.out.println(e.getMessage());
		} finally {
			try {
				br.close();
			} catch (IOException e) {
				e.printStackTrace();
			}
		}
		
		final ArrayList<Integer> output = new ArrayList<Integer>();
		
		final Graph graph = new Graph(nodes, edges);
		final List<Edge> edges = new ArrayList<Edge>(graph.getEdges());
		final DijkstraAlgorithm dijkstra = new DijkstraAlgorithm(graph);
		
		dijkstra.execute(nodes.get(1));
		
		LinkedList<Vertex> path;
		int dest = 2;
		while(dest <= vertexes)
		{
			path = dijkstra.getPath(nodes.get(dest));
			final int path_size = path.size();
			final int edges_size = edges.size();
			int p = 0;
			while(p < path_size-1)
			{
				int  i = 0;
				while(i<edges_size){

					if (edges.get(i).getSource() == path.get(p)
							&& edges.get(i).getDestination() == path.get(p + 1)) {
						if (!(output.indexOf(edges.get(i).getId()) >= 0)) {
							output.add(edges.get(i).getId());
						}
				}
					i++;
			}
			
				p++;
		}
			dest++;
		}
		
		BufferedWriter writer = null;
		try {
			writer = new BufferedWriter(new FileWriter("graph.out"));
			final int output_size = output.size();
			for (int i = 0; i < output_size; i++) {
				if (i == output.size() - 1) {
					writer.write(output.get(i).toString());
				} else
					writer.write(output.get(i).toString() + '\n');

			}
		}
			catch(IOException e)
			{
				e.printStackTrace();
			}

		 finally {
			try {
				writer.close();
			} catch (IOException e) {
				e.printStackTrace();
			}
		
		}
				
	}
	
}